# -*- coding: utf-8 -*-
"""Configure pytest."""

import os
import shutil
import tempfile

import pytest
from pytest import Session


def pytest_configure(config):  # noqa
    """Configure pytest."""
    config.addinivalue_line("markers", "doc: mark as end-to-end test.")


def pytest_sessionstart(session: "Session") -> None:
    """Setup a fresh temporary config directory for tests."""
    pytest.nessie_config_dir = tempfile.mkdtemp() + "/"
    # Instruct Confuse to keep Nessie config file in the temp location:
    os.environ["NESSIEDIR"] = pytest.nessie_config_dir


def pytest_sessionfinish(session: "Session", exitstatus: int) -> None:
    """Remove temporary config directory."""
    shutil.rmtree(pytest.nessie_config_dir)



# -*- coding: utf-8 -*-
"""Authentication tests for Nessi CLI."""
import pytest
from click.testing import CliRunner

from .test_nessie_cli import _run


@pytest.fixture(scope="module")
def vcr_config() -> dict:
    """Configures VCR to also match on HTTP headers."""
    return {"match_on": ["method", "scheme", "host", "port", "path", "query", "headers"]}


@pytest.mark.vcr
def test_bearer_auth() -> None:
    """Test the "remote show" command with bearer authentication."""
    runner = CliRunner()
    result = _run(runner, ["--json", "--auth-token", "test_token_123", "remote", "show"])
    assert "main" in result.output


@pytest.mark.vcr
def test_bearer_auth_invalid() -> None:
    """Test any command with an invalid bearer authentication token."""
    runner = CliRunner()
    result = _run(runner, ["--json", "--auth-token", "invalid", "remote", "show"], ret_val=1)
    assert "401 Client Error: Unauthorized" in result.output
